<?php
/*
  Plugin Name: Rhythm SSO by Fusionspan
  Plugin URI: https://fusionspan.com
  Description: Plugin has all the related custom setting required for SSO and roles.
  Author: Fusionspan
  Version: 1.3
  Author URI: https://fusionspan.com
 */
?>
<?php
require_once('common_functions.php');


function set_audience( $params, $connection, $redirect_to ){
    try{
        $params['audience'] = "https://api.rhythmsoftware.com";
    } catch (\Exception $e) {
        logException($e);
    }

    return $params;
}
add_action('auth0_authorize_url_params', 'set_audience', 10, 3);

/**
 * Stop the login process after WP login.
 * NOTE: The example below will break the user login process.
 *
 * @see WP_Auth0_LoginManager::do_login()
 *
 * @param integer  $user_id       - WordPress user ID for logged-in user
 * @param stdClass $userinfo      - user information object from Auth0
 * @param boolean  $is_new        - true if the user was created in WordPress, false if not
 * @param string   $id_token      - ID token for the user from Auth0
 * @param string   $access_token  - bearer access token from Auth0 (not used in implicit flow)
 * @param string   $refresh_token - refresh token from Auth0 (not used in implicit flow)
 */
function function_auth0_user_login( $user_id, $userinfo, $is_new, $id_token, $access_token, $refresh_token ) {
    try {

        if($access_token == ''){
            throw new \Exception("No access token returned from Auth0");
        }
            
        //call API to get the membership details
        $membeship_details = getMembershipDetails($access_token);

        //get user by email
        $user = get_user_by('email', $userinfo->email); //get user by email
        $wp_roles = ['administrator', 'author', 'client_admin', 'contributor', 'editor'];

        //remove all previous roles of the user
        foreach ( $user->roles as $role ){
            if(!in_array($role, $wp_roles)){
                $user->remove_role($role);
            }
        }

        if(!empty($membeship_details->securityPolicies)){

            $all_roles = getRoles($membeship_details->securityPolicies);

            //update user meta and add details
            $params = array(
                'Membership_Type' => $membeship_details->membership_type,
                'Membership_Number' => $membeship_details->membership_number,
                'Membership_Sec_Policies' => $membeship_details->securityPolicies
            );

            // add to meta
            update_user_meta(
                $user->ID, 'membership', $params
            );

            //loop for roles
            foreach($all_roles as $role){

                $member_slug = sanitize_title($role);
                add_role($member_slug, $role);
                $current_user = new WP_User( $user->ID );
                $current_user->add_role( $member_slug );
            }

        } else {

            if(empty($user->role)){
                $current_user = new WP_User( $user->ID );
                $current_user->add_role( 'subscriber' );
            }
        }

    } catch (\Exception $e) {
        logException($e);
    }
}
add_action( 'auth0_user_login', 'function_auth0_user_login', 10, 6 );

//An another custom field to set the membership API
function register_fields()
{
    register_setting('general', 'rhythm_tenant_id', 'esc_attr');
    add_settings_field('rhythm_tenant_id', '<label for="rhythm_tenant_id">'.__('Rhythm Tenant ID' , 'rhythm_tenant_id' ).'</label>' , 'print_rhythm_tenant_id_field', 'general');

    register_setting('general', 'rhythm_event_id', 'esc_attr');
    add_settings_field('rhythm_event_id', '<label for="rhythm_event_id">'.__('Rhythm Event ID' , 'rhythm_event_id' ).'</label>' , 'print_rhythm_event_id_field', 'general');
}

function print_rhythm_tenant_id_field()
{
    $value = get_option( 'rhythm_tenant_id', '' );
    echo '<input type="text" id="rhythm_tenant_id" name="rhythm_tenant_id" class="regular-text code" value="' . $value . '" />';
}

function print_rhythm_event_id_field()
{
    $value = get_option( 'rhythm_event_id', '' );
    echo '<input type="text" id="rhythm_event_id" name="rhythm_event_id" class="regular-text code" value="' . $value . '" />';
}

add_filter('admin_init', 'register_fields');
?>
